@@ -98,12 +98,13 @@ async def get_languages() -> Dict[Text, Any]:
         headers=HEADERS,
     ) as response:
         json_response = await response.json(encoding="utf-8")
+        print(json_response)
         if is_success_status(response.status):
             console.print(f"> {INFO} {GREEN_TICK} Successfully Fetched Languages")
             table = Table(show_header=True, header_style="sandy_brown")
             table.add_column("Language Code", style="green")
             table.add_column("Language")
-            table.add_column("Specialization")
+            table.add_column("Domain")
             for language_dict in json_response["data"]:
                 language_code = language_dict["code"]
                 language = language_dict["language"]
