@@ -31,8 +31,8 @@ def transcription():
     type=click.STRING,
     required=False,
     default="general",
-    help="Set to the domain specific specialization you wish to choose."
-    " If not set, a common purpose model will be used",
+    help="Set to the spefic domain you wish to choose."
+    " If not set, a general purpose model will be used",
 )
 @click.option(
     "-d",
@@ -57,7 +57,7 @@ def stream(language: Text, domain: str, device: int, log_level: Text):
         )
     sub_url, sample_rate = get_sample_rate_and_suburl_from_language(language, domain)
     if not sub_url or not sample_rate:
-        raise ValueError("Choose model language and specialization carefully.")
+        raise ValueError("Choose model language and domain carefully.")
     loop = asyncio.new_event_loop()
     loop.run_until_complete(start_stream(sub_url, sample_rate, device))
     loop.run_until_complete(get_async_http_session().close())
