@@ -236,6 +236,16 @@ def add_apps_to_table(table: Table) -> Table:
         "your input text with given confidence score. Use it with other APIs like transliteration "
         "or translation and make your NLP application cater to any language you want.",
     )
+    table.add_row(
+        f"{BOLD_START}Transcription{BOLD_END}",
+        f"{BOLD_START}transcription{BOLD_END}",
+        "neuralspace [bold red]transcription[/bold red]",
+        "Speech is the most natural choice of communication for humans. However, current AI models cannot "
+        "semantically understand speech nearly as well as text. What if you could have a bridge that lets "
+        "you use speech as an interface while also interpreting the meaning behind, to react meaningfully? "
+        "The Speech To Text (STT) App is that bridge for you. It is built with state-of-the-art AI models "
+        "for providing accurate transcriptions of any kind of speech, may it be in conversations or other forms.",
+    )
     return table
 
 
